@@ -76,8 +76,7 @@ typedef struct css_computed_content_item {
 	} data;	
 } css_computed_content_item;
   
-css_error css_computed_style_create(css_allocator_fn alloc, void *pw,
-		css_computed_style **result);
+css_error css_computed_style_create(css_computed_style **result);
 css_error css_computed_style_destroy(css_computed_style *style);
 
 css_error css_computed_style_initialise(css_computed_style *style,
@@ -269,6 +268,9 @@ uint8_t css_computed_empty_cells(
 uint8_t css_computed_float(
 		const css_computed_style *style);
   
+uint8_t css_computed_writing_mode(
+		const css_computed_style *style);
+
 uint8_t css_computed_font_style(
 		const css_computed_style *style);
   
